Odbm requires Python 3.10+ and can be easily installed using most common Python
packaging tools. We recommend installing the latest stable release from PyPI with pip:

```shell
$ pip install pythonic-dbm
```
